@@ -18,7 +18,7 @@ def consumprequesttest():
 def dealgroupquesttest():
     dealgroupquest = DealGroupsConsumption(1000069, '6862bd6012020b0fd385652905db18d4c9eaa835',
                                                '24b4e5e0e94119930686399d02439415013ab013',
-                                               'J000001', 30)
+                                               30)
 
     client = Client(dealgroupquest)
     response = client.invoke()
@@ -29,7 +29,7 @@ def dealgroupquesttest():
 def booktest():
     bookquest = Book(1000069, '6862bd6012020b0fd385652905db18d4c9eaa835',
                               '24b4e5e0e94119930686399d02439415013ab013',
-                              'J000001', 30)
+                              'J000001')
 
     client = Client(bookquest)
     response = client.invoke()
