@@ -9,7 +9,7 @@ class RTCWebSocketClient(WebSocketClient):
     def connecttest(self):
         io_loop = ioloop.IOLoop.instance()
         wsclient = RTCWebSocketClient('cecb5bd6ae79e7e1', 'acd63c7071198db36e91ffd316e7cf4ad990d350')
-        wsclient.connect("ws://10.72.253.120:80/message/websocket")
+        wsclient.connect("ws://openapi.dianping.com/message/websocket")
         try:
             io_loop.start()
         except KeyboardInterrupt:
@@ -17,7 +17,7 @@ class RTCWebSocketClient(WebSocketClient):
 
     def closetest(self):
         wsclient = RTCWebSocketClient('cecb5bd6ae79e7e1', 'acd63c7071198db36e91ffd316e7cf4ad990d350')
-        wsclient.connect("ws://10.72.251.238:80/message/websocket")
+        wsclient.connect("ws://openapi.dianping.com/message/websocket")
         wsclient.close(reason='')
 
     def reconnecttest(self):
